"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
const HackMDErrors = tslib_1.__importStar(require("./error"));
class API {
    constructor(accessToken, hackmdAPIEndpointURL = "https://api.hackmd.io/v1") {
        this.accessToken = accessToken;
        this.hackmdAPIEndpointURL = hackmdAPIEndpointURL;
        if (!accessToken) {
            throw new HackMDErrors.MissingRequiredArgument('Missing access token when creating HackMD client');
        }
        this.axios = axios_1.default.create({
            baseURL: hackmdAPIEndpointURL,
            headers: {
                "Content-Type": "application/json",
            }
        });
        this.axios.interceptors.request.use((config) => {
            config.headers.Authorization = `Bearer ${accessToken}`;
            return config;
        }, (err) => {
            return Promise.reject(err);
        });
        this.axios.interceptors.response.use((response) => {
            return response;
        }, async (err) => {
            if (!err.response) {
                return Promise.reject(err);
            }
            if (err.response.status >= 500) {
                throw new HackMDErrors.InternalServerError(`HackMD internal error (${err.response.status} ${err.response.statusText})`, err.response.status, err.response.statusText);
            }
            else {
                throw new HackMDErrors.HttpResponseError(`Received an error response (${err.response.status} ${err.response.statusText}) from HackMD`, err.response.status, err.response.statusText);
            }
        });
    }
    async getMe() {
        const { data } = await this.axios.get("me");
        return data;
    }
    async getHistory() {
        const { data } = await this.axios.get("history");
        return data;
    }
    async getNoteList() {
        const { data } = await this.axios.get("notes");
        return data;
    }
    async getNote(noteId) {
        const { data } = await this.axios.get(`notes/${noteId}`);
        return data;
    }
    async createNote(options) {
        const { data } = await this.axios.post("notes", options);
        return data;
    }
    async updateNoteContent(noteId, content) {
        await this.axios.patch(`notes/${noteId}`, { content });
    }
    async updateNote(noteId, options) {
        return await this.axios.patch(`notes/${noteId}`, options);
    }
    async deleteNote(noteId) {
        await this.axios.delete(`notes/${noteId}`);
    }
    async getTeams() {
        const { data } = await this.axios.get("teams");
        return data;
    }
    async getTeamNotes(teamPath) {
        const { data } = await this.axios.get(`teams/${teamPath}/notes`);
        return data;
    }
    async createTeamNote(teamPath, options) {
        const { data } = await this.axios.post(`teams/${teamPath}/notes`, options);
        return data;
    }
    async updateTeamNoteContent(teamPath, noteId, content) {
        await this.axios.patch(`teams/${teamPath}/notes/${noteId}`, { content });
    }
    async updateTeamNote(teamPath, noteId, options) {
        return await this.axios.patch(`teams/${teamPath}/notes/${noteId}`, options);
    }
    async deleteTeamNote(teamPath, noteId) {
        await this.axios.delete(`teams/${teamPath}/notes/${noteId}`);
    }
}
exports.default = API;
